@@ -11,7 +11,10 @@ try:
         def download_file_worker():
             time.sleep(duration)
             if rootdestroyed == False:
-                root.destroy()
+                try:
+                    root.destroy()
+                except Exception as e:
+                    pass
 
         def schedule_check(t):
             
